pub struct HealthRegistryWorker { /* private fields */ }Expand description
A worker that runs the health registry.
This is the only way to run the health registry’s liveness probing event loop. The worker
implements Supervisable, so it should be added to a Supervisor
to be managed as part of a supervision tree.